"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.textify = exports.wrapper = exports.fromNestedArray = exports.fromArray = exports.asArray = exports.asObject = exports.pipe = void 0;
const deps_1 = require("./deps");
// helpers
const pipe = (...functions) => args => functions.reduce((arg, fn) => fn(arg), args);
exports.pipe = pipe;
const comma = item => `${item},`;
const strip = item => item.substring(0, item.length - 1);
const parse = (text, def) => {
    try {
        return JSON.parse(text);
    }
    catch (e) {
        // todo add debug output to stderr
        return def;
    }
};
// table utils
const asObject = item => comma(JSON.stringify(item));
exports.asObject = asObject;
const asArray = item => comma(`[${strip(item)}]`);
exports.asArray = asArray;
const fromArray = (items) => parse(strip(items), []);
exports.fromArray = fromArray;
const fromNestedArray = (items) => parse(`[${strip(items)}]`, []);
exports.fromNestedArray = fromNestedArray;
// text utils
const textReplacers = [
    [/\(c\)/g, '©'],
    [/\(C\)/g, '©'],
    [/\(tm\)/g, '™'],
    [/\(TM\)/g, '™'],
    [/\(r\)/g, '®'],
    [/\(R\)/g, '®'],
    [/\(p\)/g, '℗'],
    [/\(P\)/g, '℗'],
    [/\+-/g, '±'],
    [/&quot;/g, '"'],
    [/&#39;/g, "'"]
];
const replacer = (text) => textReplacers.reduce((text, [target, dest]) => text.replace(target, dest), text);
const wrapper = (opts) => (text) => deps_1.wrap(text, opts);
exports.wrapper = wrapper;
// compositions
const textify = (...functions) => exports.pipe(replacer, deps_1.emojify, ...functions);
exports.textify = textify;
